@@ -404,32 +404,27 @@ review_quality_ctrl <- function(before_tbl, after_tbl, id_var) {
 #' See the "Semantic Enrichment" section in the vignette of 'eHDPrep' for more
 #' information: \code{vignette("Introduction_to_eHDPrep", package = "eHDPrep")}
 #' 
-#' This function requires three inputs:
-#' \describe{
-#' \item{data}{a numeric data frame or matrix}
-#' \item{ontology}{an ontology in the form of a directed network graph}
-#' \item{mapping_file}{A mapping file/data frame linking variables in
-#' the data frame with nodes in the ontology object}
-#' }
-#'
-#' @param data Numeric data frame or matrix containing variables present in
+#' @param data Required. Numeric data frame or matrix containing variables present in
 #'   the mapping file.
-#' @param ontology Graph containing the chosen ontology. Must be in
-#'   test format or coercible to this format.
-#' @param mapping_file Path to csv file or data frame containing mapping
+#' @param ontology Required. One of: \itemize{\item Path to ontology edge table in .csv format (String)\item Edge
+#'   table in data frame format \item Graph containing the chosen ontology -
+#'   must be in \code{\link[tidygraph:tidygraph]{tidygraph}} format or coercible
+#'   to this format.}. 
+#' @param mapping_file Required. Path to csv file or data frame containing mapping
 #'   information. Should contain two columns only. The first column should
 #'   contain column names, present in the data frame. The second column should
 #'   contain the name of entities present in the ontology object.
-#' @param root name of root node identifier in column 1 to calculate node depth
-#'   from.
+#' @param root Required. Name of root node identifier in column 1 to calculate node depth
+#'   from. 
 #' @inheritParams metavariable_info
+#' @inheritParams metavariable_agg
 #' @note A warning may be shown regarding the '.add' argument being deprecated, this is
 #'   believed to be an issue with 'tidygraph' which may be resolved in a future release: 
 #'   <https://github.com/thomasp85/tidygraph/issues/131>. Another warning may be shown regarding the 'neimode' argument being deprecated, this is
 #'   believed to be an issue with 'tidygraph' which may be resolved in a future release: 
 #'   <https://github.com/thomasp85/tidygraph/issues/156>. These warning messages are not believed to have
 #'   an effect on the functionality of 'eHDPrep'.
-#' @param ... additional arguments to pass to \code{\link[readr]{read_csv}}
+#' @param ... additional arguments to pass to \code{\link[readr]{read_csv}} when reading `mapping_file`.
 #' 
 #' @importFrom dplyr as_tibble
 #' @importFrom readr read_csv
@@ -483,7 +478,16 @@ review_quality_ctrl <- function(before_tbl, after_tbl, id_var) {
 #'  example_mapping_file, root = "root")
 #'  # see Note section of documentation for information on possible warnings.
 #' }
-semantic_enrichment <- function(data, ontology, mapping_file, mode = "in", root, ...) {
+semantic_enrichment <- function(data, ontology, mapping_file, mode = "in", root, label_attr = "name", ...) {
+  
+  # convert ontology to graph object if it is a path
+  if(is.character(ontology)) {
+    ontology_edge_tbl <- readr::read_csv(ontology)
+    ontology <- edge_tbl_to_graph(ontology_edge_tbl)
+  } else if (is.data.frame(ontology)) { # convert if data frame
+    ontology <- edge_tbl_to_graph(ontology)
+  } else {}
+  
   
   # accept both paths and R data frames for mapping_file
   if (missing(mapping_file)) {
@@ -502,6 +506,6 @@ semantic_enrichment <- function(data, ontology, mapping_file, mode = "in", root,
   ontology %>%
     join_vars_to_ontol(mapping_file, root = root, mode = mode) %>%
     metavariable_info(mode) %>%
-    metavariable_agg(data)
+    metavariable_agg(data, label_attr)
 
 }
